# keepsolid-vpn-wg-fetch

Fetches wireguard config with keepsolid email/pass

Valid region codes can be found [here](https://my.keepsolid.com/api/account/config/regions/)<br>
Examples: de, it-mil, fr, uk
